# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.models.v1_unstructured_unstructured import V1UnstructuredUnstructured  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_early_stopping_rule import V1beta1EarlyStoppingRule  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_metrics_collector_spec import V1beta1MetricsCollectorSpec  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_objective_spec import V1beta1ObjectiveSpec  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_parameter_assignment import V1beta1ParameterAssignment  # noqa: F401,E501


class V1beta1TrialSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'early_stopping_rules': 'list[V1beta1EarlyStoppingRule]',
        'failure_condition': 'str',
        'metrics_collector': 'V1beta1MetricsCollectorSpec',
        'objective': 'V1beta1ObjectiveSpec',
        'parameter_assignments': 'list[V1beta1ParameterAssignment]',
        'primary_container_name': 'str',
        'primary_pod_labels': 'dict(str, str)',
        'retain_run': 'bool',
        'run_spec': 'V1UnstructuredUnstructured',
        'success_condition': 'str'
    }

    attribute_map = {
        'early_stopping_rules': 'earlyStoppingRules',
        'failure_condition': 'failureCondition',
        'metrics_collector': 'metricsCollector',
        'objective': 'objective',
        'parameter_assignments': 'parameterAssignments',
        'primary_container_name': 'primaryContainerName',
        'primary_pod_labels': 'primaryPodLabels',
        'retain_run': 'retainRun',
        'run_spec': 'runSpec',
        'success_condition': 'successCondition'
    }

    def __init__(self, early_stopping_rules=None, failure_condition=None, metrics_collector=None, objective=None, parameter_assignments=None, primary_container_name=None, primary_pod_labels=None, retain_run=None, run_spec=None, success_condition=None):  # noqa: E501
        """V1beta1TrialSpec - a model defined in Swagger"""  # noqa: E501

        self._early_stopping_rules = None
        self._failure_condition = None
        self._metrics_collector = None
        self._objective = None
        self._parameter_assignments = None
        self._primary_container_name = None
        self._primary_pod_labels = None
        self._retain_run = None
        self._run_spec = None
        self._success_condition = None
        self.discriminator = None

        if early_stopping_rules is not None:
            self.early_stopping_rules = early_stopping_rules
        if failure_condition is not None:
            self.failure_condition = failure_condition
        if metrics_collector is not None:
            self.metrics_collector = metrics_collector
        if objective is not None:
            self.objective = objective
        self.parameter_assignments = parameter_assignments
        if primary_container_name is not None:
            self.primary_container_name = primary_container_name
        if primary_pod_labels is not None:
            self.primary_pod_labels = primary_pod_labels
        if retain_run is not None:
            self.retain_run = retain_run
        if run_spec is not None:
            self.run_spec = run_spec
        if success_condition is not None:
            self.success_condition = success_condition

    @property
    def early_stopping_rules(self):
        """Gets the early_stopping_rules of this V1beta1TrialSpec.  # noqa: E501

        Rules for early stopping techniques. Each rule should be met to early stop Trial.  # noqa: E501

        :return: The early_stopping_rules of this V1beta1TrialSpec.  # noqa: E501
        :rtype: list[V1beta1EarlyStoppingRule]
        """
        return self._early_stopping_rules

    @early_stopping_rules.setter
    def early_stopping_rules(self, early_stopping_rules):
        """Sets the early_stopping_rules of this V1beta1TrialSpec.

        Rules for early stopping techniques. Each rule should be met to early stop Trial.  # noqa: E501

        :param early_stopping_rules: The early_stopping_rules of this V1beta1TrialSpec.  # noqa: E501
        :type: list[V1beta1EarlyStoppingRule]
        """

        self._early_stopping_rules = early_stopping_rules

    @property
    def failure_condition(self):
        """Gets the failure_condition of this V1beta1TrialSpec.  # noqa: E501

        Condition when trial custom resource is failed. Condition must be in GJSON format, ref https://github.com/tidwall/gjson. For example for BatchJob: status.conditions.#(type==\"Failed\")#|#(status==\"True\")#  # noqa: E501

        :return: The failure_condition of this V1beta1TrialSpec.  # noqa: E501
        :rtype: str
        """
        return self._failure_condition

    @failure_condition.setter
    def failure_condition(self, failure_condition):
        """Sets the failure_condition of this V1beta1TrialSpec.

        Condition when trial custom resource is failed. Condition must be in GJSON format, ref https://github.com/tidwall/gjson. For example for BatchJob: status.conditions.#(type==\"Failed\")#|#(status==\"True\")#  # noqa: E501

        :param failure_condition: The failure_condition of this V1beta1TrialSpec.  # noqa: E501
        :type: str
        """

        self._failure_condition = failure_condition

    @property
    def metrics_collector(self):
        """Gets the metrics_collector of this V1beta1TrialSpec.  # noqa: E501

        Describes how metrics will be collected  # noqa: E501

        :return: The metrics_collector of this V1beta1TrialSpec.  # noqa: E501
        :rtype: V1beta1MetricsCollectorSpec
        """
        return self._metrics_collector

    @metrics_collector.setter
    def metrics_collector(self, metrics_collector):
        """Sets the metrics_collector of this V1beta1TrialSpec.

        Describes how metrics will be collected  # noqa: E501

        :param metrics_collector: The metrics_collector of this V1beta1TrialSpec.  # noqa: E501
        :type: V1beta1MetricsCollectorSpec
        """

        self._metrics_collector = metrics_collector

    @property
    def objective(self):
        """Gets the objective of this V1beta1TrialSpec.  # noqa: E501

        Describes the objective of the experiment.  # noqa: E501

        :return: The objective of this V1beta1TrialSpec.  # noqa: E501
        :rtype: V1beta1ObjectiveSpec
        """
        return self._objective

    @objective.setter
    def objective(self, objective):
        """Sets the objective of this V1beta1TrialSpec.

        Describes the objective of the experiment.  # noqa: E501

        :param objective: The objective of this V1beta1TrialSpec.  # noqa: E501
        :type: V1beta1ObjectiveSpec
        """

        self._objective = objective

    @property
    def parameter_assignments(self):
        """Gets the parameter_assignments of this V1beta1TrialSpec.  # noqa: E501

        Key-value pairs for hyperparameters and assignment values.  # noqa: E501

        :return: The parameter_assignments of this V1beta1TrialSpec.  # noqa: E501
        :rtype: list[V1beta1ParameterAssignment]
        """
        return self._parameter_assignments

    @parameter_assignments.setter
    def parameter_assignments(self, parameter_assignments):
        """Sets the parameter_assignments of this V1beta1TrialSpec.

        Key-value pairs for hyperparameters and assignment values.  # noqa: E501

        :param parameter_assignments: The parameter_assignments of this V1beta1TrialSpec.  # noqa: E501
        :type: list[V1beta1ParameterAssignment]
        """
        if parameter_assignments is None:
            raise ValueError("Invalid value for `parameter_assignments`, must not be `None`")  # noqa: E501

        self._parameter_assignments = parameter_assignments

    @property
    def primary_container_name(self):
        """Gets the primary_container_name of this V1beta1TrialSpec.  # noqa: E501

        Name of training container where actual model training is running  # noqa: E501

        :return: The primary_container_name of this V1beta1TrialSpec.  # noqa: E501
        :rtype: str
        """
        return self._primary_container_name

    @primary_container_name.setter
    def primary_container_name(self, primary_container_name):
        """Sets the primary_container_name of this V1beta1TrialSpec.

        Name of training container where actual model training is running  # noqa: E501

        :param primary_container_name: The primary_container_name of this V1beta1TrialSpec.  # noqa: E501
        :type: str
        """

        self._primary_container_name = primary_container_name

    @property
    def primary_pod_labels(self):
        """Gets the primary_pod_labels of this V1beta1TrialSpec.  # noqa: E501

        Label that determines if pod needs to be injected by Katib sidecar container  # noqa: E501

        :return: The primary_pod_labels of this V1beta1TrialSpec.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._primary_pod_labels

    @primary_pod_labels.setter
    def primary_pod_labels(self, primary_pod_labels):
        """Sets the primary_pod_labels of this V1beta1TrialSpec.

        Label that determines if pod needs to be injected by Katib sidecar container  # noqa: E501

        :param primary_pod_labels: The primary_pod_labels of this V1beta1TrialSpec.  # noqa: E501
        :type: dict(str, str)
        """

        self._primary_pod_labels = primary_pod_labels

    @property
    def retain_run(self):
        """Gets the retain_run of this V1beta1TrialSpec.  # noqa: E501

        Whether to retain the trial run object after completed.  # noqa: E501

        :return: The retain_run of this V1beta1TrialSpec.  # noqa: E501
        :rtype: bool
        """
        return self._retain_run

    @retain_run.setter
    def retain_run(self, retain_run):
        """Sets the retain_run of this V1beta1TrialSpec.

        Whether to retain the trial run object after completed.  # noqa: E501

        :param retain_run: The retain_run of this V1beta1TrialSpec.  # noqa: E501
        :type: bool
        """

        self._retain_run = retain_run

    @property
    def run_spec(self):
        """Gets the run_spec of this V1beta1TrialSpec.  # noqa: E501

        Raw text for the trial run spec. This can be any generic Kubernetes runtime object. The trial operator should create the resource as written, and let the corresponding resource controller (e.g. tf-operator) handle the rest.  # noqa: E501

        :return: The run_spec of this V1beta1TrialSpec.  # noqa: E501
        :rtype: V1UnstructuredUnstructured
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this V1beta1TrialSpec.

        Raw text for the trial run spec. This can be any generic Kubernetes runtime object. The trial operator should create the resource as written, and let the corresponding resource controller (e.g. tf-operator) handle the rest.  # noqa: E501

        :param run_spec: The run_spec of this V1beta1TrialSpec.  # noqa: E501
        :type: V1UnstructuredUnstructured
        """

        self._run_spec = run_spec

    @property
    def success_condition(self):
        """Gets the success_condition of this V1beta1TrialSpec.  # noqa: E501

        Condition when trial custom resource is succeeded. Condition must be in GJSON format, ref https://github.com/tidwall/gjson. For example for BatchJob: status.conditions.#(type==\"Complete\")#|#(status==\"True\")#  # noqa: E501

        :return: The success_condition of this V1beta1TrialSpec.  # noqa: E501
        :rtype: str
        """
        return self._success_condition

    @success_condition.setter
    def success_condition(self, success_condition):
        """Sets the success_condition of this V1beta1TrialSpec.

        Condition when trial custom resource is succeeded. Condition must be in GJSON format, ref https://github.com/tidwall/gjson. For example for BatchJob: status.conditions.#(type==\"Complete\")#|#(status==\"True\")#  # noqa: E501

        :param success_condition: The success_condition of this V1beta1TrialSpec.  # noqa: E501
        :type: str
        """

        self._success_condition = success_condition

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TrialSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TrialSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2019 The Kubeflow Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import multiprocessing

from kubernetes import client, config

from kubeflow.katib.constants import constants
from kubeflow.katib.utils import utils


class KatibClient(object):

    def __init__(self, config_file=None, context=None,  # pylint: disable=too-many-arguments
                 client_configuration=None, persist_config=True):
        """
        katibclient constructor
        :param config_file: kubeconfig file, defaults to ~/.kube/config
        :param context: kubernetes context
        :param client_configuration: kubernetes configuration object
        :param persist_config:
        """
        self.in_cluster = None
        if config_file or not utils.is_running_in_k8s():
            config.load_kube_config(
                config_file=config_file,
                context=context,
                client_configuration=client_configuration,
                persist_config=persist_config)
            self.in_cluster = False
        else:
            config.load_incluster_config()
            self.in_cluster = True

        self.api_instance = client.CustomObjectsApi()

    def _is_ipython(self):
        """Returns whether we are running in notebook."""
        try:
            import IPython
            ipy = IPython.get_ipython()
            if ipy is None:
                return False
        except ImportError:
            return False
        return True

    def create_experiment(self, exp_object, namespace=None):
        """
        Create the katib experiment
        :param exp_object: experiment object
        :param namespace: defaults to current or default namespace
        :return: created experiment dict
        """

        if namespace is None:
            namespace = utils.set_katib_namespace(exp_object)
        try:
            outputs = self.api_instance.create_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.EXPERIMENT_PLURAL,
                exp_object)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->create_namespaced_custom_object:\
         %s\n" % e)

        if self._is_ipython():
            if self.in_cluster:
                import IPython
                IPython.display.display(IPython.display.HTML(
                    'Katib Experiment {} '
                    'link <a href="/_/katib/#/katib/hp_monitor/{}/{}" target="_blank">here</a>'.format(
                        exp_object.metadata.name, namespace, exp_object.metadata.name)
                ))
        return outputs

    def get_experiment(self, name=None, namespace=None):
        """
        Get single experiment or all experiment
        :param name: existing experiment name optional
        :param namespace: defaults to current or default namespace
        :return: experiment dict
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        if name:
            thread = self.api_instance.get_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.EXPERIMENT_PLURAL,
                name,
                async_req=True)

            katibexp = None
            try:
                katibexp = thread.get(constants.APISERVER_TIMEOUT)
            except multiprocessing.TimeoutError:
                raise RuntimeError("Timeout trying to get katib experiment.")
            except client.rest.ApiException as e:
                raise RuntimeError(
                    "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
          %s\n" % e)
            except Exception as e:
                raise RuntimeError(
                    "There was a problem to get experiment {0} in namespace {1}. Exception: \
          {2} ".format(name, namespace, e))

        else:
            thread = self.api_instance.list_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.EXPERIMENT_PLURAL,
                async_req=True)

            katibexp = None
            try:
                katibexp = thread.get(constants.APISERVER_TIMEOUT)
            except multiprocessing.TimeoutError:
                raise RuntimeError("Timeout trying to get Experiment.")
            except client.rest.ApiException as e:
                raise RuntimeError(
                    "Exception when calling CustomObjectsApi->list_namespaced_custom_object:\
          %s\n" % e)
            except Exception as e:
                raise RuntimeError(
                    "There was a problem to get experiment in namespace {0}. \
          Exception: {1} ".format(namespace, e))

        return katibexp

    def get_suggestion(self, name=None, namespace=None):
        """
        Get experiment's suggestion.
        If name is empty returns all suggestion in requested namespace.
        :param name: existing suggestion name optional
        :param namespace: defaults to current or default namespace
        :return: suggestion dict
        """

        if namespace is None:
            namespace = utils.get_default_target_namespace()

        if name:
            thread = self.api_instance.get_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.SUGGESTION_PLURAL,
                name,
                async_req=True)

            katib_suggestion = None
            try:
                katib_suggestion = thread.get(constants.APISERVER_TIMEOUT)
            except multiprocessing.TimeoutError:
                raise RuntimeError("Timeout trying to get Katib suggestion")
            except client.rest.ApiException as e:
                raise RuntimeError(
                    "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
          %s\n" % e)
            except Exception as e:
                raise RuntimeError(
                    "There was a problem to get suggestion {0} in namespace {1}. Exception: \
          {2} ".format(name, namespace, e))

        else:
            thread = self.api_instance.list_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.SUGGESTION_PLURAL,
                async_req=True)

            katib_suggestion = None
            try:
                katib_suggestion = thread.get(constants.APISERVER_TIMEOUT)
            except multiprocessing.TimeoutError:
                raise RuntimeError("Timeout trying to get Katib suggestion")
            except client.rest.ApiException as e:
                raise RuntimeError(
                    "Exception when calling CustomObjectsApi->list_namespaced_custom_object:\
          %s\n" % e)
            except Exception as e:
                raise RuntimeError(
                    "There was a problem to get suggestions in namespace {0}. \
          Exception: {1} ".format(namespace, e))

        return katib_suggestion

    def delete_experiment(self, name, namespace=None):
        """
        Delete experiment
        :param name: experiment name required
        :param namespace: defaults to current or default namespace
        :return: status dict
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        try:
            return self.api_instance.delete_namespaced_custom_object(
                constants.KUBEFLOW_GROUP,
                constants.KATIB_VERSION,
                namespace,
                constants.EXPERIMENT_PLURAL,
                name,
                body=client.V1DeleteOptions())
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->delete_namespaced_custom_object:\
         %s\n" % e)

    def list_experiments(self, namespace=None):
        """
        List all experiments
        :param namespace: defaults to current or default namespace
        :return: list of experiment name with status as list
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        thread = self.api_instance.list_namespaced_custom_object(
            constants.KUBEFLOW_GROUP,
            constants.KATIB_VERSION,
            namespace=namespace,
            plural=constants.EXPERIMENT_PLURAL,
            async_req=True)

        katibexp = None
        try:
            katibexp = thread.get(constants.APISERVER_TIMEOUT)
            result = []
            for i in katibexp.get("items"):
                output = {}
                output["name"] = i.get("metadata", {}).get("name")
                output["status"] = i.get("status", {}).get(
                    "conditions", [])[-1].get("type")
                result.append(output)
        except multiprocessing.TimeoutError:
            raise RuntimeError("Timeout trying to get katib experiment.")
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
          %s\n" % e)
        except Exception as e:
            raise RuntimeError(
                "There was a problem to get experiments in namespace {1}. Exception: \
          {2} ".format(namespace, e))
        return result

    def get_experiment_status(self, name, namespace=None):
        """Returns experiment status, such as Running, Failed or Succeeded.
        Args:
          :param name: An experiment name. required
          :param namespace: defaults to current or default namespace.
          :return: status str
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        katibexp = self.get_experiment(name, namespace=namespace)
        last_condition = katibexp.get("status", {}).get("conditions", [])[-1]
        return last_condition.get("type", "")

    def is_experiment_succeeded(self, name, namespace=None):
        """Returns true if experiment succeeded; false otherwise.
        Args:
          :param name: An experiment name. required
          :param namespace: defaults to current or default namespace. optional
          :return: status bool
        """
        experiment_status = self.get_experiment_status(
            name, namespace=namespace)
        return experiment_status.lower() == "succeeded"

    def list_trials(self, name=None, namespace=None):
        """
        Get trials of an experiment
        :param name: existing experiment name
        :param namespace: defaults to current or default namespace
        :return: trials name with status as list
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        thread = self.api_instance.list_namespaced_custom_object(
            constants.KUBEFLOW_GROUP,
            constants.KATIB_VERSION,
            namespace=namespace,
            plural=constants.TRIAL_PLURAL,
            async_req=True)

        katibtrial = None
        try:
            katibtrial = thread.get(constants.APISERVER_TIMEOUT)
            result = []
            for i in katibtrial.get("items"):
                output = {}
                if i.get("metadata", {}).get("ownerReferences")[0].get("name") == name:
                    output["name"] = i.get("metadata", {}).get("name")
                    output["status"] = i.get("status", {}).get(
                        "conditions", [])[-1].get("type")
                    result.append(output)
        except multiprocessing.TimeoutError:
            raise RuntimeError("Timeout trying to getkatib experiment.")
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
          %s\n" % e)
        except Exception as e:
            raise RuntimeError(
                "There was a problem to get experiment {0} in namespace {1}. Exception: \
          {2} ".format(name, namespace, e))
        return result

    def get_optimal_hyperparameters(self, name=None, namespace=None):
        """
        Get status, currentOptimalTrial with parameterAssignments
        :param name: existing experiment name
        :param namespace: defaults to current or default namespace
        :return: dict with status, currentOptimalTrial with parameterAssignments of an experiment
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        katibexp = self.get_experiment(name, namespace=namespace)
        result = {}
        result["currentOptimalTrial"] = katibexp.get(
            "status", {}).get("currentOptimalTrial")

        return result



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kubeflow.katib
from kubeflow.katib.models.v1beta1_suggestion import V1beta1Suggestion  # noqa: E501
from kubeflow.katib.rest import ApiException


class TestV1beta1Suggestion(unittest.TestCase):
    """V1beta1Suggestion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1beta1Suggestion(self):
        """Test V1beta1Suggestion"""
        # FIXME: construct object with mandatory attributes with example values
        # model = katib.models.v1beta1_suggestion.V1beta1Suggestion()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.models.v1_unstructured_unstructured import V1UnstructuredUnstructured  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_config_map_source import V1beta1ConfigMapSource  # noqa: F401,E501


class V1beta1TrialSource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'config_map': 'V1beta1ConfigMapSource',
        'trial_spec': 'V1UnstructuredUnstructured'
    }

    attribute_map = {
        'config_map': 'configMap',
        'trial_spec': 'trialSpec'
    }

    def __init__(self, config_map=None, trial_spec=None):  # noqa: E501
        """V1beta1TrialSource - a model defined in Swagger"""  # noqa: E501

        self._config_map = None
        self._trial_spec = None
        self.discriminator = None

        if config_map is not None:
            self.config_map = config_map
        if trial_spec is not None:
            self.trial_spec = trial_spec

    @property
    def config_map(self):
        """Gets the config_map of this V1beta1TrialSource.  # noqa: E501

        ConfigMap spec represents a reference to ConfigMap  # noqa: E501

        :return: The config_map of this V1beta1TrialSource.  # noqa: E501
        :rtype: V1beta1ConfigMapSource
        """
        return self._config_map

    @config_map.setter
    def config_map(self, config_map):
        """Sets the config_map of this V1beta1TrialSource.

        ConfigMap spec represents a reference to ConfigMap  # noqa: E501

        :param config_map: The config_map of this V1beta1TrialSource.  # noqa: E501
        :type: V1beta1ConfigMapSource
        """

        self._config_map = config_map

    @property
    def trial_spec(self):
        """Gets the trial_spec of this V1beta1TrialSource.  # noqa: E501

        TrialSpec represents trial template in unstructured format  # noqa: E501

        :return: The trial_spec of this V1beta1TrialSource.  # noqa: E501
        :rtype: V1UnstructuredUnstructured
        """
        return self._trial_spec

    @trial_spec.setter
    def trial_spec(self, trial_spec):
        """Sets the trial_spec of this V1beta1TrialSource.

        TrialSpec represents trial template in unstructured format  # noqa: E501

        :param trial_spec: The trial_spec of this V1beta1TrialSource.  # noqa: E501
        :type: V1UnstructuredUnstructured
        """

        self._trial_spec = trial_spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TrialSource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TrialSource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.models.v1beta1_graph_config import V1beta1GraphConfig  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_operation import V1beta1Operation  # noqa: F401,E501


class V1beta1NasConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'graph_config': 'V1beta1GraphConfig',
        'operations': 'list[V1beta1Operation]'
    }

    attribute_map = {
        'graph_config': 'graphConfig',
        'operations': 'operations'
    }

    def __init__(self, graph_config=None, operations=None):  # noqa: E501
        """V1beta1NasConfig - a model defined in Swagger"""  # noqa: E501

        self._graph_config = None
        self._operations = None
        self.discriminator = None

        if graph_config is not None:
            self.graph_config = graph_config
        if operations is not None:
            self.operations = operations

    @property
    def graph_config(self):
        """Gets the graph_config of this V1beta1NasConfig.  # noqa: E501


        :return: The graph_config of this V1beta1NasConfig.  # noqa: E501
        :rtype: V1beta1GraphConfig
        """
        return self._graph_config

    @graph_config.setter
    def graph_config(self, graph_config):
        """Sets the graph_config of this V1beta1NasConfig.


        :param graph_config: The graph_config of this V1beta1NasConfig.  # noqa: E501
        :type: V1beta1GraphConfig
        """

        self._graph_config = graph_config

    @property
    def operations(self):
        """Gets the operations of this V1beta1NasConfig.  # noqa: E501


        :return: The operations of this V1beta1NasConfig.  # noqa: E501
        :rtype: list[V1beta1Operation]
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        """Sets the operations of this V1beta1NasConfig.


        :param operations: The operations of this V1beta1NasConfig.  # noqa: E501
        :type: list[V1beta1Operation]
        """

        self._operations = operations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1NasConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1NasConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.models.v1beta1_early_stopping_rule import V1beta1EarlyStoppingRule  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_parameter_assignment import V1beta1ParameterAssignment  # noqa: F401,E501


class V1beta1TrialAssignment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'early_stopping_rules': 'list[V1beta1EarlyStoppingRule]',
        'name': 'str',
        'parameter_assignments': 'list[V1beta1ParameterAssignment]'
    }

    attribute_map = {
        'early_stopping_rules': 'earlyStoppingRules',
        'name': 'name',
        'parameter_assignments': 'parameterAssignments'
    }

    def __init__(self, early_stopping_rules=None, name=None, parameter_assignments=None):  # noqa: E501
        """V1beta1TrialAssignment - a model defined in Swagger"""  # noqa: E501

        self._early_stopping_rules = None
        self._name = None
        self._parameter_assignments = None
        self.discriminator = None

        if early_stopping_rules is not None:
            self.early_stopping_rules = early_stopping_rules
        if name is not None:
            self.name = name
        if parameter_assignments is not None:
            self.parameter_assignments = parameter_assignments

    @property
    def early_stopping_rules(self):
        """Gets the early_stopping_rules of this V1beta1TrialAssignment.  # noqa: E501

        Rules for early stopping techniques Contains rule name, value and comparison type  # noqa: E501

        :return: The early_stopping_rules of this V1beta1TrialAssignment.  # noqa: E501
        :rtype: list[V1beta1EarlyStoppingRule]
        """
        return self._early_stopping_rules

    @early_stopping_rules.setter
    def early_stopping_rules(self, early_stopping_rules):
        """Sets the early_stopping_rules of this V1beta1TrialAssignment.

        Rules for early stopping techniques Contains rule name, value and comparison type  # noqa: E501

        :param early_stopping_rules: The early_stopping_rules of this V1beta1TrialAssignment.  # noqa: E501
        :type: list[V1beta1EarlyStoppingRule]
        """

        self._early_stopping_rules = early_stopping_rules

    @property
    def name(self):
        """Gets the name of this V1beta1TrialAssignment.  # noqa: E501

        Name of the suggestion  # noqa: E501

        :return: The name of this V1beta1TrialAssignment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1TrialAssignment.

        Name of the suggestion  # noqa: E501

        :param name: The name of this V1beta1TrialAssignment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parameter_assignments(self):
        """Gets the parameter_assignments of this V1beta1TrialAssignment.  # noqa: E501

        Suggestion results with Trial parameters  # noqa: E501

        :return: The parameter_assignments of this V1beta1TrialAssignment.  # noqa: E501
        :rtype: list[V1beta1ParameterAssignment]
        """
        return self._parameter_assignments

    @parameter_assignments.setter
    def parameter_assignments(self, parameter_assignments):
        """Sets the parameter_assignments of this V1beta1TrialAssignment.

        Suggestion results with Trial parameters  # noqa: E501

        :param parameter_assignments: The parameter_assignments of this V1beta1TrialAssignment.  # noqa: E501
        :type: list[V1beta1ParameterAssignment]
        """

        self._parameter_assignments = parameter_assignments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TrialAssignment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TrialAssignment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2019 kubeflow.org.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os

def is_running_in_k8s():
  return os.path.isdir('/var/run/secrets/kubernetes.io/')


def get_current_k8s_namespace():
  with open('/var/run/secrets/kubernetes.io/serviceaccount/namespace', 'r') as f:
    return f.readline()


def get_default_target_namespace():
  if not is_running_in_k8s():
    return 'default'
  return get_current_k8s_namespace()


def set_katib_namespace(katib):
  katib_namespace = katib.metadata.namespace
  namespace = katib_namespace or get_default_target_namespace()
  return namespace



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class V1beta1GraphConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_sizes': 'list[int]',
        'num_layers': 'int',
        'output_sizes': 'list[int]'
    }

    attribute_map = {
        'input_sizes': 'inputSizes',
        'num_layers': 'numLayers',
        'output_sizes': 'outputSizes'
    }

    def __init__(self, input_sizes=None, num_layers=None, output_sizes=None):  # noqa: E501
        """V1beta1GraphConfig - a model defined in Swagger"""  # noqa: E501

        self._input_sizes = None
        self._num_layers = None
        self._output_sizes = None
        self.discriminator = None

        if input_sizes is not None:
            self.input_sizes = input_sizes
        if num_layers is not None:
            self.num_layers = num_layers
        if output_sizes is not None:
            self.output_sizes = output_sizes

    @property
    def input_sizes(self):
        """Gets the input_sizes of this V1beta1GraphConfig.  # noqa: E501


        :return: The input_sizes of this V1beta1GraphConfig.  # noqa: E501
        :rtype: list[int]
        """
        return self._input_sizes

    @input_sizes.setter
    def input_sizes(self, input_sizes):
        """Sets the input_sizes of this V1beta1GraphConfig.


        :param input_sizes: The input_sizes of this V1beta1GraphConfig.  # noqa: E501
        :type: list[int]
        """

        self._input_sizes = input_sizes

    @property
    def num_layers(self):
        """Gets the num_layers of this V1beta1GraphConfig.  # noqa: E501


        :return: The num_layers of this V1beta1GraphConfig.  # noqa: E501
        :rtype: int
        """
        return self._num_layers

    @num_layers.setter
    def num_layers(self, num_layers):
        """Sets the num_layers of this V1beta1GraphConfig.


        :param num_layers: The num_layers of this V1beta1GraphConfig.  # noqa: E501
        :type: int
        """

        self._num_layers = num_layers

    @property
    def output_sizes(self):
        """Gets the output_sizes of this V1beta1GraphConfig.  # noqa: E501


        :return: The output_sizes of this V1beta1GraphConfig.  # noqa: E501
        :rtype: list[int]
        """
        return self._output_sizes

    @output_sizes.setter
    def output_sizes(self, output_sizes):
        """Sets the output_sizes of this V1beta1GraphConfig.


        :param output_sizes: The output_sizes of this V1beta1GraphConfig.  # noqa: E501
        :type: list[int]
        """

        self._output_sizes = output_sizes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1GraphConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1GraphConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.models.v1_time import V1Time  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_observation import V1beta1Observation  # noqa: F401,E501
from kubeflow.katib.models.v1beta1_trial_condition import V1beta1TrialCondition  # noqa: F401,E501


class V1beta1TrialStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'completion_time': 'V1Time',
        'conditions': 'list[V1beta1TrialCondition]',
        'last_reconcile_time': 'V1Time',
        'observation': 'V1beta1Observation',
        'start_time': 'V1Time'
    }

    attribute_map = {
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'last_reconcile_time': 'lastReconcileTime',
        'observation': 'observation',
        'start_time': 'startTime'
    }

    def __init__(self, completion_time=None, conditions=None, last_reconcile_time=None, observation=None, start_time=None):  # noqa: E501
        """V1beta1TrialStatus - a model defined in Swagger"""  # noqa: E501

        self._completion_time = None
        self._conditions = None
        self._last_reconcile_time = None
        self._observation = None
        self._start_time = None
        self.discriminator = None

        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if last_reconcile_time is not None:
            self.last_reconcile_time = last_reconcile_time
        if observation is not None:
            self.observation = observation
        if start_time is not None:
            self.start_time = start_time

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1TrialStatus.  # noqa: E501

        Represents time when the Trial was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC  # noqa: E501

        :return: The completion_time of this V1beta1TrialStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1TrialStatus.

        Represents time when the Trial was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC  # noqa: E501

        :param completion_time: The completion_time of this V1beta1TrialStatus.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1TrialStatus.  # noqa: E501

        List of observed runtime conditions for this Trial.  # noqa: E501

        :return: The conditions of this V1beta1TrialStatus.  # noqa: E501
        :rtype: list[V1beta1TrialCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1TrialStatus.

        List of observed runtime conditions for this Trial.  # noqa: E501

        :param conditions: The conditions of this V1beta1TrialStatus.  # noqa: E501
        :type: list[V1beta1TrialCondition]
        """

        self._conditions = conditions

    @property
    def last_reconcile_time(self):
        """Gets the last_reconcile_time of this V1beta1TrialStatus.  # noqa: E501

        Represents last time when the Trial was reconciled. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC.  # noqa: E501

        :return: The last_reconcile_time of this V1beta1TrialStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._last_reconcile_time

    @last_reconcile_time.setter
    def last_reconcile_time(self, last_reconcile_time):
        """Sets the last_reconcile_time of this V1beta1TrialStatus.

        Represents last time when the Trial was reconciled. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC.  # noqa: E501

        :param last_reconcile_time: The last_reconcile_time of this V1beta1TrialStatus.  # noqa: E501
        :type: V1Time
        """

        self._last_reconcile_time = last_reconcile_time

    @property
    def observation(self):
        """Gets the observation of this V1beta1TrialStatus.  # noqa: E501

        Results of the Trial - objectives and other metrics values.  # noqa: E501

        :return: The observation of this V1beta1TrialStatus.  # noqa: E501
        :rtype: V1beta1Observation
        """
        return self._observation

    @observation.setter
    def observation(self, observation):
        """Sets the observation of this V1beta1TrialStatus.

        Results of the Trial - objectives and other metrics values.  # noqa: E501

        :param observation: The observation of this V1beta1TrialStatus.  # noqa: E501
        :type: V1beta1Observation
        """

        self._observation = observation

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1TrialStatus.  # noqa: E501

        Represents time when the Trial was acknowledged by the Trial controller. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC  # noqa: E501

        :return: The start_time of this V1beta1TrialStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1TrialStatus.

        Represents time when the Trial was acknowledged by the Trial controller. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC  # noqa: E501

        :param start_time: The start_time of this V1beta1TrialStatus.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TrialStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TrialStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Copyright 2019 kubeflow.org.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os

# Global CRD version
KATIB_VERSION = os.environ.get('EXPERIMENT_VERSION', 'v1beta1')

# Katib K8S constants
KUBEFLOW_GROUP = 'kubeflow.org'
EXPERIMENT_PLURAL = 'experiments'
SUGGESTION_PLURAL = 'suggestions'
TRIAL_PLURAL = 'trials'

# How long to wait in seconds for requests to the ApiServer
APISERVER_TIMEOUT = 120



# Copyright 2019 kubeflow.org.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import setuptools

with open('requirements.txt') as f:
    REQUIRES = f.readlines()

setuptools.setup(
    name='kubeflow-katib',
    version='0.10.0',
    author="Kubeflow Authors",
    author_email='premnath.vel@gmail.com',
    license="Apache License Version 2.0",
    url="https://github.com/kubeflow/katib/tree/master/sdk/python/v1beta1",
    description="Katib Python SDK for APIVersion v1beta1",
    long_description="Katib Python SDK for APIVersion v1beta1",
    packages=setuptools.find_packages(
        include=("kubeflow*")),
    package_data={},
    include_package_data=False,
    zip_safe=False,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=REQUIRES
)
